package com.zfire.jiasm.syncdata.download.order.repair;

import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.zfire.jiasm.syncdata.base.BaseService;
import com.zfire.jiasm.syncdata.dao.mapper.*;
import com.zfire.jiasm.syncdata.parameter.OrderPar;
import com.zfire.jiasm.syncdata.parameter.ReAppointment;
import com.zfire.jiasm.syncdata.plus.entity.*;
import com.zfire.jiasm.syncdata.plus.service.*;
import com.zfire.jiasm.syncdata.response.WebsitSH;
import com.zfire.jiasm.syncdata.service.OrderService;
import com.zfire.jiasm.syncdata.service.PublicService;
import lombok.extern.slf4j.Slf4j;
import org.jetbrains.annotations.NotNull;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 格力品牌维修工单下载后落本地数据表
 *    落业务表 - 修改下载主表处理结果
 */
@Slf4j
@Component
public class RepairBusiness {

    @Resource
    RepairBusiness repairBusiness;
    @Resource
    ItfTblAssignDownloadService itfTblAssignDownloadService;
    @Resource
    RepairDownloadMapper repairDownloadMapper;
    @Resource
    BaseService baseService;
    @Resource
    OrderBaseService orderBaseService;
    @Resource
    OrderService orderService;
    @Resource
    OrderApplyDispatchService orderApplyDispatchService;
    @Resource
    AssignDownloadMapper assignDownloadMapper;
    @Resource
    ItfTblAssignMxDownloadService itfTblAssignMxDownloadService;
    @Resource
    RepairMxDownloadMapper repairMxDownloadMapper;
    @Resource
    PublicService publicService;
    @Resource
    OrderInstallService orderInstallService;
    @Resource
    OrderProductService orderProductService;
    @Resource
    ItfTblAssignFkmxDownloadService itfTblAssignFkmxDownloadService;
    @Resource
    OrderRepairOperatingLogService orderRepairOperatingLogService;
    @Resource
    ItfTblAssignSatisfactionDownloadService itfTblAssignSatisfactionDownloadService;
    @Resource
    OrderAppraiseService orderAppraiseService;
    @Resource
    AppraiseMapper appraiseMapper;
    @Resource
    AssignSatisfactionDownloadMapper assignSatisfactionDownloadMapper;
    @Resource
    FaGreeSmsService faGreeSmsService;
    @Resource
    ItfTblAssignXzydDownloadService itfTblAssignXzydDownloadService;
    @Resource
    OrderInformationService orderInformationService;
    @Resource
    ItfTblAssignAppointmentDownloadService itfTblAssignAppointmentDownloadService;



    // 1：工单落入本地表
    @Scheduled(fixedDelay = 1 * 10 * 1000)
    public void inputOrder() {
        /*if (1 == 1) {
            return;
        }*/


        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        List<ItfTblAssignDownload> repairRec = new ArrayList<>();

        // 提取品牌信息
        Brand brand = baseService.getBrand();
        if (brand == null) {
            return;
        }

        // 提取品牌商对应的大类信息
        Map<String, List<SysDictRef>> sysDictRefDLMap = publicService.getStringListMap(brand);
        // 提取品牌商对应的小类信息
        Map<String, List<SysDictRef>> sysDictRefXLMap = publicService.getListMap(brand);
        // 提取品牌商对应的系列信息
        Map<String, List<SysDictRef>> sysDictRefXiLieMap = publicService.getMap(brand);

        // 提取待落本地表的数据
        repairRec = itfTblAssignDownloadService.lambdaQuery()
                .eq(ItfTblAssignDownload::getSynStatus,0)
                .orderByAsc(ItfTblAssignDownload::getSynReqId)
                .list();

        if (repairRec.size()<1){
            log.info("暂无待处理的维修工单: {}",sdf.format(new Date()));
            return;
        }

        log.info("维修工单落本地表开始处理: {}",sdf.format(new Date()));

        // 按任务号download_task_no，按单来处理
        for (ItfTblAssignDownload item: repairRec){
            // 新增
            repairBusiness.addOrder(brand, item, sysDictRefDLMap, sysDictRefXLMap, sysDictRefXiLieMap);
        }

        log.info("维修工单落本地表处理完成: {}",sdf.format(new Date()));
    }

    @Transactional(rollbackFor = Exception.class)
    public void addOrder(Brand brand, ItfTblAssignDownload item,
                          Map<String, List<SysDictRef>> sysDictRefDLMap,
                          Map<String, List<SysDictRef>> sysDictRefXLMap,
                          Map<String, List<SysDictRef>> sysDictRefXiLieMap) {

        List<ItfTblAssignXzydDownload> yds = itfTblAssignXzydDownloadService.lambdaQuery()
                .eq(ItfTblAssignXzydDownload::getDownloadTaskNo,item.getDownloadTaskNo()).list();

        // 新增 TL_SynDataFrom_tbl_assign_batch
        // TL_SynDataFrom_tbl_assign 主单的 syn_req_id
        // 处理维修工单主表数据
        OrderBase order = generateOrder(brand, item, yds);
        // 处理工单师傅
        publicService.getOrderWorker(order);
        // 获取工单扩展信息
        getOrderInstall(item, order);
        // 处理维修单明细表 TL_SynDataFrom_tbl_assign_mx
        generateMx(brand, item, order, sysDictRefDLMap, sysDictRefXLMap, sysDictRefXiLieMap);
        // 处理维修单过程反馈表 放入操作日志表 TL_SynDataFrom_tbl_assign_fkmx
        generateFkmx(brand, item, order);
        // 处理用户评价数据 TL_SynDataFrom_tbl_assign_satisfaction
        generateSstisfaction(brand, item, sysDictRefDLMap, order);
        // 阅读要求数据处理 TL_SynDataFrom_tbl_assign_xzyd
        generateXzyd(brand, yds, order);
        // 用户预约改约数据处理 TL_SynDataFrom_tbl_assign_appointment
        generateAppointment(item, order);
    }

    private void generateAppointment(ItfTblAssignDownload item, OrderBase order) {
        // 新增工单，直接修改主表预约时间最近一次的数据修改
        List<ItfTblAssignAppointmentDownload> appoint = itfTblAssignAppointmentDownloadService.lambdaQuery()
                .eq(ItfTblAssignAppointmentDownload::getDownloadTaskNo, item.getDownloadTaskNo())
                .orderByAsc(ItfTblAssignAppointmentDownload::getSynReqId).list();
        for (ItfTblAssignAppointmentDownload a:appoint){
            OrderBase up = new OrderBase();
            up.setId(order.getId());
            up.setFirstAppointmentId(a.getCzren());
            up.setExpectStartTime(a.getKssj());
            up.setExpectEndTime(a.getJssj());
            orderBaseService.updateById(up);
            ItfTblAssignAppointmentDownload u = new ItfTblAssignAppointmentDownload();
            u.setSynReqId(a.getSynReqId());
            u.setSynStatus(1);
            u.setSynTime(new Date());
            itfTblAssignAppointmentDownloadService.updateById(u);
        }
    }

    private void generateXzyd(Brand brand, List<ItfTblAssignXzydDownload> yds, OrderBase order) {
        for (ItfTblAssignXzydDownload yd: yds){
            OrderInformation add = new OrderInformation();
            add.setId(String.valueOf(yd.getXzid()));
            add.setAskCategoryId(yd.getXzyqlb());
            add.setAskCategoryName(yd.getXzyq());
            add.setOrderBaseId(order.getId());
            add.setCreateBy(yd.getCreatedBy());
            add.setCreateTime(yd.getCreatedDate());
            add.setUpdateBy(yd.getLastModifiedBy());
            add.setUpdateTime(yd.getLastModifiedDate());
            add.setReadStatus(yd.getYdbz());
            add.setReadName(yd.getYdrmc());
            add.setReadTime(yd.getYdsj());
            WebsitSH websitSH = publicService.WebsitToSH(yd.getWdno(), brand.getBrandId());
            add.setWebsitId(websitSH.getWdId());
            add.setWebsitName(websitSH.getWdmc());

            orderInformationService.save(add);
            ItfTblAssignXzydDownload up = new ItfTblAssignXzydDownload();
            up.setSynReqId(yd.getSynReqId());
            up.setSynStatus(1);
            up.setSynTime(new Date());
            itfTblAssignXzydDownloadService.updateById(up);
        }
    }

    private void generateSstisfaction(Brand brand, ItfTblAssignDownload item, Map<String, List<SysDictRef>> sysDictRefDLMap, OrderBase order) {
        List<ItfTblAssignSatisfactionDownload> satis = itfTblAssignSatisfactionDownloadService.lambdaQuery()
                .eq(ItfTblAssignSatisfactionDownload::getDownloadTaskNo, item.getDownloadTaskNo())
                .list();

        for (ItfTblAssignSatisfactionDownload s:satis){
            // 查看是否已同步
            ReAppointment request = new ReAppointment();
            request.setId(s.getId());
            OrderAppraise old = appraiseMapper.getAppraise(request);
            if (old!=null){
                upSyncstatus(s.getSynReqId(), 9, "评价已同步，忽略更新");
                continue;
            }
            // 查看该工单有无较早前下载相同的评价
            List<ItfTblAssignSatisfactionDownload> rec = itfTblAssignSatisfactionDownloadService.lambdaQuery()
                    .lt(ItfTblAssignSatisfactionDownload::getSynReqId,s.getSynReqId())
                    .eq(ItfTblAssignSatisfactionDownload::getPgid,s.getPgid())
                    .le(ItfTblAssignSatisfactionDownload::getLastModifiedDate,s.getLastModifiedDate())
                    .eq(ItfTblAssignSatisfactionDownload::getPjly,s.getPjly()).list();
            if (rec!=null && rec.size()>0){
                upSyncstatus(s.getSynReqId(), 9 ,"评价已同步，忽略更新");
                continue;
            }
            // 判断评价是否为中差评，如果是中差评，检查上一条记录是否为中差评，如果是则新插入的不需要再申诉
            // 这里并没查表， 需要一张表类工单系统 TL_get_satisfaction_pjly(itf_tbl_satisfaction_list)
            Integer canInsert =1;
            // 检查fa_order_repair是否有一条sxlx = 0的首评记录
            if (s.getSxlx().equals(0) && s.getSynStatus().equals(0)){
                ReAppointment r = new ReAppointment();
                r.setId(String.valueOf(s.getSynReqId()));
                ItfTblAssignSatisfactionDownload sa = assignSatisfactionDownloadMapper.getSatisfaction(r);
                if (sa !=null){
                    canInsert = 0;
                }
            }
             // 只插入一条sxlx = 0的首评记录
            if (canInsert.equals(1)){
                // 增加评价记录
                WebsitSH websitSH = addappraise(brand, sysDictRefDLMap, s);
                // 增加差评短信
                addcpsms(order, s, websitSH);
            }

            // 已评价过，则更新追评  新增时无，不需操作 appraise_datetime字段新增时无操作，只需查工单基础表，判断不为null即可
            // 这里改为首次评价
            upOrderBasePJ(order, s);

            // 修改同步状态
            upSatisfactionSynstatus(s);
        }
    }

    private void addcpsms(OrderBase order, ItfTblAssignSatisfactionDownload s, WebsitSH websitSH) {
        if (s.getPjnr().equals("3") || s.getPjnr().indexOf("不满意")>0){
            if (StringUtils.isNotEmpty(s.getHfwdno()) && s.getHfwdno().equals("99999999")){
                FaGreeSms fs = new FaGreeSms();
                fs.setSynTaskNo(UUID.randomUUID().toString());
                fs.setWorkerOrderNo(order.getId());
                fs.setAzorwx(2);
                fs.setFjid(String.valueOf(s.getPgid()));
                fs.setFjwd(s.getHfwdno());
                Random random = new Random(System.currentTimeMillis());
                fs.setFsma(String.valueOf(random.nextInt(10000)));
                fs.setFsnr("您收到一张客户的投诉工单，请及时处理！工单号：" + String.valueOf(s.getPgid()) +
                        ",服务人员：" + order.getWorkerName());
                fs.setSjid(websitSH.getWdlxdh());
                fs.setYhlb(2);
                faGreeSmsService.save(fs);
            }
        }
    }

    @NotNull
    private WebsitSH addappraise(Brand brand, Map<String, List<SysDictRef>> sysDictRefDLMap, ItfTblAssignSatisfactionDownload s) {
        Boolean canAppeal = Boolean.TRUE;
        Integer appeal = 0;
        ReAppointment rq = new ReAppointment();

        if(StringUtils.isNotEmpty(s.getPjnr())){
            if (s.getPjnr().equals("1") || s.getPjnr().equals("满意")){
                canAppeal=Boolean.FALSE;
            }
        }
        // 检查上一条记录是否为中差评，如果是则新插入的不需要再申诉

        if (canAppeal){
            ReAppointment req = new ReAppointment();
            req.setId(String.valueOf(s.getPgid()));
            OrderAppraise id = appraiseMapper.getOldId(req);
            if (id !=null){
                appeal = 0;
            } else {
                appeal = 1;
            }
        }

        rq.setId(String.valueOf(s.getSynReqId()));
        OrderAppraise add = assignSatisfactionDownloadMapper.getOrderAppraise(rq);

        // rvisit_websit_id 单独处理
        WebsitSH websitSH = publicService.WebsitToSH(s.getHfwdno(), brand.getBrandId());
        add.setRvisitWebsitId(websitSH.getWdId());
        add.setRvisitWebsitName(websitSH.getWdmc());
        // splb 商品大类  单独处理
        add.setMainId(sysDictRefDLMap.get(String.valueOf(s.getSplb())).get(0).getDictCode());
        // can_appeal 是否可发起申诉   单独处理
        add.setCanAppeal(appeal);
        orderAppraiseService.save(add);
        return websitSH;
    }

    private void upOrderBasePJ(OrderBase order, ItfTblAssignSatisfactionDownload s) {
        OrderBase upOrder = new OrderBase();
        upOrder.setId(order.getId());
        upOrder.setAppraiseTime(s.getCreatedDate());
        // 原 评价:1=差评,2=中评,3=好评,0=未评价,4=剔除,5=其他
        if (StringUtils.isEmpty(s.getPjnr())){
            upOrder.setAppraiseStatus("N");
        }
        if (s.getPjnr().equals("1") || s.getPjnr().equals("满意")){
            upOrder.setAppraiseStatus("A");
        } else if (s.getPjnr().equals("2") || s.getPjnr().equals("一般")){
            upOrder.setAppraiseStatus("B");
        } else if (s.getPjnr().equals("3") || s.getPjnr().equals("不满意") ||
                s.getPjnr().indexOf("差")>0 || s.getPjnr().indexOf("不满")>0){
            upOrder.setAppraiseStatus("C");
        } else {
            upOrder.setAppraiseStatus("O");
        }
        orderBaseService.updateById(upOrder);
    }

    private void upSatisfactionSynstatus(ItfTblAssignSatisfactionDownload s) {
        ItfTblAssignSatisfactionDownload ups = new ItfTblAssignSatisfactionDownload();
        ups.setSynReqId(s.getSynReqId());
        ups.setSynStatus(1);
        ups.setSynTime(new Date());
        itfTblAssignSatisfactionDownloadService.updateById(ups);
    }

    private void upSyncstatus(Long synReqId, Integer synStatus ,
                              String msg) {
        ItfTblAssignSatisfactionDownload up = new ItfTblAssignSatisfactionDownload();
        up.setSynReqId(synReqId);
        up.setSynStatus(synStatus);
        up.setSynTime(new Date());
        up.setSynErrMsg(msg);
        itfTblAssignSatisfactionDownloadService.updateById(up);
    }

    private void generateFkmx(Brand brand, ItfTblAssignDownload item, OrderBase order) {
        List<ItfTblAssignFkmxDownload> fkmxRec = new ArrayList<>();
        List<OrderRepairOperatingLog> orols = new ArrayList<>();
        List<ItfTblAssignFkmxDownload> ups = new ArrayList<>();

        fkmxRec = itfTblAssignFkmxDownloadService.lambdaQuery()
                .eq(ItfTblAssignFkmxDownload::getDownloadTaskNo, item.getDownloadTaskNo())
                .eq(ItfTblAssignFkmxDownload::getSynStatus,0)
                .orderByAsc(ItfTblAssignFkmxDownload::getCreatedDate,ItfTblAssignFkmxDownload::getFkid)
                .list();
        for (ItfTblAssignFkmxDownload fkmx :fkmxRec){
            // 查看是否存在，存在为修改
            // 新增时是不会存在的，所以这里只做新增
            OrderRepairOperatingLog add = new OrderRepairOperatingLog();
            add.setWebsitName(order.getWebsitName());
            add.setWebsitId(order.getWebsitId());
            add.setOrderBaseId(order.getId());
            add.setCustomerName(order.getUserName());
            add.setCustomerPhone(order.getUserMobile());
            add.setType(fkmx.getFklb());
            add.setContent(fkmx.getFknr());
            add.setFeedback(fkmx.getFkjg());
            add.setOperator(fkmx.getFkren());
            add.setOperatorNumber(fkmx.getFkrenmc());
            WebsitSH websitSH = publicService.WebsitToSH(fkmx.getFkwdno(), brand.getBrandId());
            add.setOperateWebsit(websitSH.getWdmc());
            add.setWebsitPhone(websitSH.getWdlxdh());
            add.setWorkerOrderState(order.getOrderStatus());// 反馈时的工单状态
            add.setBeforeOrderState(order.getLastOrderStatus());// 操作前工单状态 - 上一流程状态
            add.setBeforeAppointState(order.getDispatchStatus());// 操作前派工状态
            add.setOrderState("DJS"); // 操作后工单状态
            // 总部下来的工单统一为待接收状态-派工状态
            add.setAppointState("DJS"); // 操作后派工状态
            // 附件地址 todo
            add.setPgguid(order.getPgguid());
            add.setFkmxguid(fkmx.getFkmxguid());
            add.setFkid(String.valueOf(fkmx.getFkid()));
            add.setPgid(fkmx.getPgid());
            add.setBrandFileId(fkmx.getScid());
            add.setBrandFileName(fkmx.getScwj());
            add.setWjid(fkmx.getWjid());
            add.setReqSourceNum(fkmx.getQqlyxh());
            add.setUploadNotifyFlag(0);
            add.setCreateTime(fkmx.getFksj());
            add.setUpdateTime(fkmx.getLastModifiedDate());
            add.setCreateBy(fkmx.getCreatedBy());
            add.setUpdateBy(fkmx.getLastModifiedBy());
            orols.add(add);
            ItfTblAssignFkmxDownload u = new ItfTblAssignFkmxDownload();
            u.setSynReqId(fkmx.getSynReqId());
            u.setSynStatus(1);
            u.setSynTime(new Date());
            ups.add(u);
        }
        if (orols.size()>0){
            orderRepairOperatingLogService.saveBatch(orols);
            orols.clear();
            itfTblAssignFkmxDownloadService.updateBatchById(ups);
            ups.clear();
        }
    }

    private void getOrderInstall(ItfTblAssignDownload item, OrderBase order) {
        OrderInstall oit = new OrderInstall();
        oit.setOrderBaseId(order.getId());
        oit.setExtendField1(item.getExtjson1());
        oit.setExtendField2(item.getExtjson2());
        oit.setExtendField3(item.getExtjson3());
        oit.setExtendField4(item.getExtjson4());
        oit.setExtendField5(item.getExtjson5());
        oit.setCreateBy(order.getCreateBy());
        oit.setCreateTime(order.getCreateTime());
        oit.setUpdateBy(order.getUpdateBy());
        oit.setUpdateTime(order.getUpdateTime());
        orderInstallService.save(oit);
    }

    private void generateMx(Brand brand, ItfTblAssignDownload item, OrderBase order,
                            Map<String, List<SysDictRef>> sysDictRefDLMap,
                            Map<String, List<SysDictRef>> sysDictRefXLMap,
                            Map<String, List<SysDictRef>> sysDictRefXiLieMap) {
        List<ItfTblAssignMxDownload> mxRec = new ArrayList<>();
        List<OrderProduct> addmx = new ArrayList<>();
        List<ItfTblAssignMxDownload> ups = new ArrayList<>();


        // 明取明细表数据
        mxRec = itfTblAssignMxDownloadService.lambdaQuery()
                .eq(ItfTblAssignMxDownload::getDownloadTaskNo, item.getDownloadTaskNo())
                .eq(ItfTblAssignMxDownload::getSynStatus,0)
                .orderByAsc(ItfTblAssignMxDownload::getSynStatus)
                .list();
        for (ItfTblAssignMxDownload rec:mxRec){
            // 提取维修工单明细数据对象
            OrderPar mxreq = new OrderPar();
            mxreq.setSynReqId(Long.valueOf(rec.getSynReqId()));
            mxreq.setBrandId(brand.getBrandId());
            OrderProduct op = repairMxDownloadMapper.getMx(mxreq);

            // 其他部分参数赋值
            op.setOrderBaseId(order.getId());
            op.setPgguid(item.getPgguid());
            op.setMainId(order.getMainId());
            op.setMainName(order.getMainName());
            op.setMainId(sysDictRefDLMap.get(String.valueOf(rec.getSpid())).get(0).getDictCode());
            op.setMainName(sysDictRefDLMap.get(String.valueOf(rec.getSpid())).get(0).getDictValue());
            if (!rec.getXlid().equals(0L)){
                op.setSmallId(sysDictRefXLMap.get(String.valueOf(rec.getXlid())).get(0).getDictCode());
                op.setSmallName(sysDictRefXLMap.get(String.valueOf(rec.getXlid())).get(0).getDictValue());
            } else {
                op.setSmallId(String.valueOf(rec.getXlid()));
                op.setSmallName(rec.getXlmc());
            }

            if (!rec.getXiid().equals("0") && sysDictRefXiLieMap.containsKey(rec.getXiid())){
                op.setSeriesId(sysDictRefXiLieMap.get(rec.getXiid()).get(0).getDictCode());
                op.setSeriesName(sysDictRefXiLieMap.get(rec.getXiid()).get(0).getDictValue());
            } else {
                op.setSeriesId(rec.getXiid());
                op.setSeriesName(rec.getXimc());
            }
            addmx.add(op);

            ItfTblAssignMxDownload up = new ItfTblAssignMxDownload();
            up.setSynReqId(rec.getSynReqId());
            up.setSynStatus(1);
            up.setSynReqTime(new Date());
            ups.add(up);
        }

        if (addmx.size()>0){
            orderProductService.saveBatch(addmx);
            addmx.clear();
            itfTblAssignMxDownloadService.updateBatchById(ups);
            ups.clear();
        }
    }

    private OrderBase generateOrder(Brand brand, ItfTblAssignDownload item, List<ItfTblAssignXzydDownload> yds) {
        Boolean isChildInfo = Boolean.FALSE;

        if (yds !=null && yds.size()>0){
            isChildInfo = Boolean.TRUE;
        }

        OrderBase order = saveOrderBase(brand, item, isChildInfo);

        // 更新 修改时更新 新增时无需此操作 可以先放进来，是修改不到数据的
        // 维修工单产品信息 (维修网点、维修网点名称) websit_id，websit_name
        // order_product 无维修网点信息，所以不用做

        // 采集表需要做上面的操作 order_repair_detail  新增时也无需操作，加上也不会出错
        /*OrderPar request = new OrderPar();
        request.setOrderNo(order.getId());
        detailOrderRepairMapper.updateWebsitMessage(request);*/


        // 新增或是修改都要加  新增是一定要做的
        // 总部维修单为待审批改派时 若本地表无改派数据则生成改派数据
        if (order.getOrderStatus().equals("B5")){
            generateDispatch(order);
        }

        // 原 本地维修单表状态为5 待审批  同步过来的工单状态不是待审批时
        // 修改接品自动审核  新增时条件不成立的

        // 增加判断是否有未处理的待改派，如果广佛有待改派但总部工单不是待改派，直接更新改派标志
        // 新增时了样不用操作

        // 增加处理采集数据下载 新增不用操作
            /*if ((order.getOrderStatus().equals("B41") || order.getOrderStatus().equals("B102"))){

            }*/
        // 如果是家用的工单，且工单状态是待中心派工或待网点派工时，写入派嘉讯茂  不做

        // 修改同步状态
        upItfTblAssignDownloadStatus(item, order);

        return order;
    }

    private OrderBase saveOrderBase(Brand brand, ItfTblAssignDownload item, Boolean isChildInfo) {
        // 获取维修工单主表数据
        OrderPar orderPar = new OrderPar();
        orderPar.setSynReqId(item.getSynReqId());
        orderPar.setBrandId(brand.getBrandId());
        OrderBase order = repairDownloadMapper.getOrderBase(orderPar);
        if (isChildInfo){
            order.setIsChildInfo("YES");
        }
        // 部分属性值重置
        orderService.setParame(brand, order);
        // 新增
        orderBaseService.save(order);
        return order;
    }

    public void upItfTblAssignDownloadStatus(ItfTblAssignDownload item, OrderBase order){
        ItfTblAssignDownload up = new ItfTblAssignDownload();
        up.setSynReqId(item.getSynReqId());
        up.setSynStatus(1);
        up.setSynTime(new Date());
        up.setSynErrMsg("成功");
        itfTblAssignDownloadService.updateById(up);

        OrderPar prepar = new OrderPar();
        prepar.setSynReqId(item.getSynReqId());
        prepar.setPgid(order.getPgid());
        assignDownloadMapper.updateStatus(prepar);
    }

    private void generateDispatch(OrderBase order) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");

        List<String> parame = new ArrayList<>();
        parame.add(order.getWebsitId());
        parame.add(order.getReceWebsitId());
        // 改派表中查看是否有待审的数据
        List<OrderApplyDispatch> rec = orderApplyDispatchService.lambdaQuery()
                .eq(OrderApplyDispatch::getOrderBaseId, order.getId())
                .eq(OrderApplyDispatch::getExamineStatus,"WAIT")
                .in(OrderApplyDispatch::getWebsitId,parame).list();
        if (rec.size()<1){
            // 生成改派数据 从维修工单表中读取数据
            OrderApplyDispatch addn = new OrderApplyDispatch();
            addn.setOrderBaseId(order.getId());
            addn.setPgid(order.getPgid());
            addn.setType("REPAIR");
            addn.setWebsitId(order.getWebsitId());
            addn.setWebsitName(order.getWebsitName());
            addn.setApplyContent("申请改派");
            addn.setExamineStatus("WAIT");
            addn.setUserName(order.getUserName());
            addn.setUserMobile(order.getUserMobile());
            addn.setReserveTime(order.getAppointmentTime());
            addn.setReservePeriod(sdf.format(order.getAppointmentTime()));
            addn.setMainId(Integer.valueOf(order.getMainId()));
            addn.setMainName(order.getMainName());
            addn.setCreateTime(order.getCreateTime());
            addn.setUpdateTime(order.getUpdateTime());
            orderApplyDispatchService.save(addn);
        }
    }


}
